Class: Google::Cloud::Sql::V1beta4::Ack

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb

Overview

Acknowledges data received by the client or server.

Instance Attribute Summary collapse

Instance Attribute Details

#received_offset::Integer

Returns Required. The absolute number of bytes processed in the session.

Returns:

  • (::Integer)

    Required. The absolute number of bytes processed in the session.



162
163
164
165
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 162

class Ack
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end