Class: Google::Cloud::Sql::V1beta4::CloneContext
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::CloneContext
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb
Overview
Database instance clone context.
Instance Attribute Summary collapse
-
#allocated_ip_range ⇒ ::String
The name of the allocated ip range for the private ip Cloud SQL instance.
-
#bin_log_coordinates ⇒ ::Google::Cloud::Sql::V1beta4::BinLogCoordinates
Binary log coordinates, if specified, identify the position up to which the source instance is cloned.
-
#database_names ⇒ ::Array<::String>
(SQL Server only) Clone only the specified databases from the source instance.
-
#destination_instance_name ⇒ ::String
Name of the Cloud SQL instance to be created as a clone.
-
#destination_network ⇒ ::String
Optional.
-
#destination_project ⇒ ::String
Optional.
-
#kind ⇒ ::String
This is always
sql#cloneContext. -
#pitr_timestamp_ms ⇒ ::Integer
Reserved for future use.
-
#point_in_time ⇒ ::Google::Protobuf::Timestamp
Timestamp, if specified, identifies the time to which the source instance is cloned.
-
#preferred_secondary_zone ⇒ ::String
Optional.
-
#preferred_zone ⇒ ::String
Optional.
-
#source_instance_deletion_time ⇒ ::Google::Protobuf::Timestamp
The timestamp used to identify the time when the source instance is deleted.
Instance Attribute Details
#allocated_ip_range ⇒ ::String
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bin_log_coordinates ⇒ ::Google::Cloud::Sql::V1beta4::BinLogCoordinates
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#database_names ⇒ ::Array<::String>
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_instance_name ⇒ ::String
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_network ⇒ ::String
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_project ⇒ ::String
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pitr_timestamp_ms ⇒ ::Integer
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#point_in_time ⇒ ::Google::Protobuf::Timestamp
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#preferred_secondary_zone ⇒ ::String
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#preferred_zone ⇒ ::String
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_instance_deletion_time ⇒ ::Google::Protobuf::Timestamp
512 513 514 515 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 512 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |