Class: Google::Cloud::Sql::V1beta4::DataPacket

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb

Overview

Contains data being sent or received by the database.

Instance Attribute Summary collapse

Instance Attribute Details

#data::String

Returns Required. Raw data being sent or received by the database.

Returns:

  • (::String)

    Required. Raw data being sent or received by the database.



153
154
155
156
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 153

class DataPacket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#first_byte_offset::Integer

Returns Optional. The absolute byte offset of the first byte in this payload. 0 for new connections or resumed connections that hasn't acked any bytes from server. Non-zero for resumed connections.

Returns:

  • (::Integer)

    Optional. The absolute byte offset of the first byte in this payload. 0 for new connections or resumed connections that hasn't acked any bytes from server. Non-zero for resumed connections



153
154
155
156
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 153

class DataPacket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end