Class: Google::Cloud::Sql::V1beta4::DnsNameMapping

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb

Overview

DNS metadata.

Defined Under Namespace

Modules: ConnectionType, DnsScope, RecordManager

Instance Attribute Summary collapse

Instance Attribute Details

#connection_type::Google::Cloud::Sql::V1beta4::DnsNameMapping::ConnectionType (readonly)

Returns Output only. The connection type of the DNS name.

Returns:



1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1009

class DnsNameMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The connection type of the DNS name.
  module ConnectionType
    # Unknown connection type.
    CONNECTION_TYPE_UNSPECIFIED = 0

    # Public IP.
    PUBLIC = 1

    # Private services access (private IP).
    PRIVATE_SERVICES_ACCESS = 2

    # Private Service Connect.
    PRIVATE_SERVICE_CONNECT = 3
  end

  # The scope that the DNS name applies to.
  module DnsScope
    # DNS scope not set. This value should not be used.
    DNS_SCOPE_UNSPECIFIED = 0

    # Indicates an instance-level DNS name.
    INSTANCE = 1

    # Indicates a cluster-level DNS name.
    CLUSTER = 2
  end

  # The system responsible for managing the DNS record.
  module RecordManager
    # Record manager not set. This value should not be used.
    RECORD_MANAGER_UNSPECIFIED = 0

    # The record may be managed by the customer. It is not automatically
    # managed by Cloud SQL automation.
    CUSTOMER = 1

    # The record is managed by Cloud SQL, which will create, update, and delete
    # the DNS records for the zone automatically when the Cloud SQL database
    # instance is created or updated.
    CLOUD_SQL_AUTOMATION = 2
  end
end

#dns_scope::Google::Cloud::Sql::V1beta4::DnsNameMapping::DnsScope (readonly)

Returns Output only. The scope that the DNS name applies to.

Returns:



1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1009

class DnsNameMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The connection type of the DNS name.
  module ConnectionType
    # Unknown connection type.
    CONNECTION_TYPE_UNSPECIFIED = 0

    # Public IP.
    PUBLIC = 1

    # Private services access (private IP).
    PRIVATE_SERVICES_ACCESS = 2

    # Private Service Connect.
    PRIVATE_SERVICE_CONNECT = 3
  end

  # The scope that the DNS name applies to.
  module DnsScope
    # DNS scope not set. This value should not be used.
    DNS_SCOPE_UNSPECIFIED = 0

    # Indicates an instance-level DNS name.
    INSTANCE = 1

    # Indicates a cluster-level DNS name.
    CLUSTER = 2
  end

  # The system responsible for managing the DNS record.
  module RecordManager
    # Record manager not set. This value should not be used.
    RECORD_MANAGER_UNSPECIFIED = 0

    # The record may be managed by the customer. It is not automatically
    # managed by Cloud SQL automation.
    CUSTOMER = 1

    # The record is managed by Cloud SQL, which will create, update, and delete
    # the DNS records for the zone automatically when the Cloud SQL database
    # instance is created or updated.
    CLOUD_SQL_AUTOMATION = 2
  end
end

#name::String (readonly)

Returns Output only. The DNS name.

Returns:

  • (::String)

    Output only. The DNS name.



1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1009

class DnsNameMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The connection type of the DNS name.
  module ConnectionType
    # Unknown connection type.
    CONNECTION_TYPE_UNSPECIFIED = 0

    # Public IP.
    PUBLIC = 1

    # Private services access (private IP).
    PRIVATE_SERVICES_ACCESS = 2

    # Private Service Connect.
    PRIVATE_SERVICE_CONNECT = 3
  end

  # The scope that the DNS name applies to.
  module DnsScope
    # DNS scope not set. This value should not be used.
    DNS_SCOPE_UNSPECIFIED = 0

    # Indicates an instance-level DNS name.
    INSTANCE = 1

    # Indicates a cluster-level DNS name.
    CLUSTER = 2
  end

  # The system responsible for managing the DNS record.
  module RecordManager
    # Record manager not set. This value should not be used.
    RECORD_MANAGER_UNSPECIFIED = 0

    # The record may be managed by the customer. It is not automatically
    # managed by Cloud SQL automation.
    CUSTOMER = 1

    # The record is managed by Cloud SQL, which will create, update, and delete
    # the DNS records for the zone automatically when the Cloud SQL database
    # instance is created or updated.
    CLOUD_SQL_AUTOMATION = 2
  end
end

#record_manager::Google::Cloud::Sql::V1beta4::DnsNameMapping::RecordManager (readonly)

Returns Output only. The manager for this DNS record.

Returns:



1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1009

class DnsNameMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The connection type of the DNS name.
  module ConnectionType
    # Unknown connection type.
    CONNECTION_TYPE_UNSPECIFIED = 0

    # Public IP.
    PUBLIC = 1

    # Private services access (private IP).
    PRIVATE_SERVICES_ACCESS = 2

    # Private Service Connect.
    PRIVATE_SERVICE_CONNECT = 3
  end

  # The scope that the DNS name applies to.
  module DnsScope
    # DNS scope not set. This value should not be used.
    DNS_SCOPE_UNSPECIFIED = 0

    # Indicates an instance-level DNS name.
    INSTANCE = 1

    # Indicates a cluster-level DNS name.
    CLUSTER = 2
  end

  # The system responsible for managing the DNS record.
  module RecordManager
    # Record manager not set. This value should not be used.
    RECORD_MANAGER_UNSPECIFIED = 0

    # The record may be managed by the customer. It is not automatically
    # managed by Cloud SQL automation.
    CUSTOMER = 1

    # The record is managed by Cloud SQL, which will create, update, and delete
    # the DNS records for the zone automatically when the Cloud SQL database
    # instance is created or updated.
    CLOUD_SQL_AUTOMATION = 2
  end
end