Class: Google::Cloud::Sql::V1beta4::ExecuteSqlPayload

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb

Overview

The request payload used to execute SQL statements.

Defined Under Namespace

Modules: PartialResultMode

Instance Attribute Summary collapse

Instance Attribute Details

#application::String



1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#auto_iam_authn::Boolean



1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#database::String



1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#partial_result_mode::Google::Cloud::Sql::V1beta4::ExecuteSqlPayload::PartialResultMode



1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#password_secret_version::String



1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#row_limit::Integer



1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#sql_statement::String



1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#user::String



1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end