Class: Google::Cloud::Sql::V1beta4::ExportContext::SqlExportOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb

Defined Under Namespace

Classes: MysqlExportOptions, PostgresExportOptions

Instance Attribute Summary collapse

Instance Attribute Details

#mysql_export_options::Google::Cloud::Sql::V1beta4::ExportContext::SqlExportOptions::MysqlExportOptions



1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1319

class SqlExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for exporting from MySQL.
  # @!attribute [rw] master_data
  #   @return [::Google::Protobuf::Int32Value]
  #     Option to include SQL statement required to set up replication. If set
  #     to `1`, the dump file includes a CHANGE MASTER TO statement with the
  #     binary log coordinates, and --set-gtid-purged is set to ON. If set to
  #     `2`, the CHANGE MASTER TO statement is written as a SQL comment and
  #     has no effect. If set to any value other than `1`, --set-gtid-purged
  #     is set to OFF.
  class MysqlExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Options for exporting from a Cloud SQL for PostgreSQL instance.
  # @!attribute [rw] clean
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Use this option to include DROP <code>&lt;object&gt;</code>
  #     SQL statements. Use these statements to delete database objects before
  #     running the import operation.
  # @!attribute [rw] if_exists
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Option to include an IF EXISTS SQL statement with each DROP
  #     statement produced by clean.
  class PostgresExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#parallel::Google::Protobuf::BoolValue

Returns Optional. Whether or not the export should be parallel.

Returns:



1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1319

class SqlExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for exporting from MySQL.
  # @!attribute [rw] master_data
  #   @return [::Google::Protobuf::Int32Value]
  #     Option to include SQL statement required to set up replication. If set
  #     to `1`, the dump file includes a CHANGE MASTER TO statement with the
  #     binary log coordinates, and --set-gtid-purged is set to ON. If set to
  #     `2`, the CHANGE MASTER TO statement is written as a SQL comment and
  #     has no effect. If set to any value other than `1`, --set-gtid-purged
  #     is set to OFF.
  class MysqlExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Options for exporting from a Cloud SQL for PostgreSQL instance.
  # @!attribute [rw] clean
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Use this option to include DROP <code>&lt;object&gt;</code>
  #     SQL statements. Use these statements to delete database objects before
  #     running the import operation.
  # @!attribute [rw] if_exists
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Option to include an IF EXISTS SQL statement with each DROP
  #     statement produced by clean.
  class PostgresExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#postgres_export_options::Google::Cloud::Sql::V1beta4::ExportContext::SqlExportOptions::PostgresExportOptions

Returns Optional. Options for exporting from a Cloud SQL for PostgreSQL instance.

Returns:



1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1319

class SqlExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for exporting from MySQL.
  # @!attribute [rw] master_data
  #   @return [::Google::Protobuf::Int32Value]
  #     Option to include SQL statement required to set up replication. If set
  #     to `1`, the dump file includes a CHANGE MASTER TO statement with the
  #     binary log coordinates, and --set-gtid-purged is set to ON. If set to
  #     `2`, the CHANGE MASTER TO statement is written as a SQL comment and
  #     has no effect. If set to any value other than `1`, --set-gtid-purged
  #     is set to OFF.
  class MysqlExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Options for exporting from a Cloud SQL for PostgreSQL instance.
  # @!attribute [rw] clean
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Use this option to include DROP <code>&lt;object&gt;</code>
  #     SQL statements. Use these statements to delete database objects before
  #     running the import operation.
  # @!attribute [rw] if_exists
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Option to include an IF EXISTS SQL statement with each DROP
  #     statement produced by clean.
  class PostgresExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#schema_only::Google::Protobuf::BoolValue

Returns Export only schemas.

Returns:



1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1319

class SqlExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for exporting from MySQL.
  # @!attribute [rw] master_data
  #   @return [::Google::Protobuf::Int32Value]
  #     Option to include SQL statement required to set up replication. If set
  #     to `1`, the dump file includes a CHANGE MASTER TO statement with the
  #     binary log coordinates, and --set-gtid-purged is set to ON. If set to
  #     `2`, the CHANGE MASTER TO statement is written as a SQL comment and
  #     has no effect. If set to any value other than `1`, --set-gtid-purged
  #     is set to OFF.
  class MysqlExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Options for exporting from a Cloud SQL for PostgreSQL instance.
  # @!attribute [rw] clean
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Use this option to include DROP <code>&lt;object&gt;</code>
  #     SQL statements. Use these statements to delete database objects before
  #     running the import operation.
  # @!attribute [rw] if_exists
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Option to include an IF EXISTS SQL statement with each DROP
  #     statement produced by clean.
  class PostgresExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#tables::Array<::String>

Returns Tables to export, or that were exported, from the specified database. If you specify tables, specify one and only one database. For PostgreSQL instances, you can specify only one table.

Returns:

  • (::Array<::String>)

    Tables to export, or that were exported, from the specified database. If you specify tables, specify one and only one database. For PostgreSQL instances, you can specify only one table.



1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1319

class SqlExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for exporting from MySQL.
  # @!attribute [rw] master_data
  #   @return [::Google::Protobuf::Int32Value]
  #     Option to include SQL statement required to set up replication. If set
  #     to `1`, the dump file includes a CHANGE MASTER TO statement with the
  #     binary log coordinates, and --set-gtid-purged is set to ON. If set to
  #     `2`, the CHANGE MASTER TO statement is written as a SQL comment and
  #     has no effect. If set to any value other than `1`, --set-gtid-purged
  #     is set to OFF.
  class MysqlExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Options for exporting from a Cloud SQL for PostgreSQL instance.
  # @!attribute [rw] clean
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Use this option to include DROP <code>&lt;object&gt;</code>
  #     SQL statements. Use these statements to delete database objects before
  #     running the import operation.
  # @!attribute [rw] if_exists
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Option to include an IF EXISTS SQL statement with each DROP
  #     statement produced by clean.
  class PostgresExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#threads::Google::Protobuf::Int32Value

Returns Optional. The number of threads to use for parallel export.

Returns:



1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1319

class SqlExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for exporting from MySQL.
  # @!attribute [rw] master_data
  #   @return [::Google::Protobuf::Int32Value]
  #     Option to include SQL statement required to set up replication. If set
  #     to `1`, the dump file includes a CHANGE MASTER TO statement with the
  #     binary log coordinates, and --set-gtid-purged is set to ON. If set to
  #     `2`, the CHANGE MASTER TO statement is written as a SQL comment and
  #     has no effect. If set to any value other than `1`, --set-gtid-purged
  #     is set to OFF.
  class MysqlExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Options for exporting from a Cloud SQL for PostgreSQL instance.
  # @!attribute [rw] clean
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Use this option to include DROP <code>&lt;object&gt;</code>
  #     SQL statements. Use these statements to delete database objects before
  #     running the import operation.
  # @!attribute [rw] if_exists
  #   @return [::Google::Protobuf::BoolValue]
  #     Optional. Option to include an IF EXISTS SQL statement with each DROP
  #     statement produced by clean.
  class PostgresExportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end