Class: Google::Cloud::Sql::V1beta4::InstancesListResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::InstancesListResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb
Overview
Database instances list response.
Instance Attribute Summary collapse
-
#items ⇒ ::Array<::Google::Cloud::Sql::V1beta4::DatabaseInstance>
List of database instance resources.
-
#kind ⇒ ::String
This is always
sql#instancesList. -
#next_page_token ⇒ ::String
The continuation token, used to page through large result sets.
-
#warnings ⇒ ::Array<::Google::Cloud::Sql::V1beta4::ApiWarning>
List of warnings that occurred while handling the request.
Instance Attribute Details
#items ⇒ ::Array<::Google::Cloud::Sql::V1beta4::DatabaseInstance>
Returns List of database instance resources.
1774 1775 1776 1777 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1774 class InstancesListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#instancesList.
1774 1775 1776 1777 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1774 class InstancesListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results.
1774 1775 1776 1777 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1774 class InstancesListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warnings ⇒ ::Array<::Google::Cloud::Sql::V1beta4::ApiWarning>
Returns List of warnings that occurred while handling the request.
1774 1775 1776 1777 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1774 class InstancesListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |