Class: Google::Cloud::Sql::V1beta4::OnPremisesConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb

Overview

On-premises instance configuration.

Defined Under Namespace

Modules: SslOption

Instance Attribute Summary collapse

Instance Attribute Details

#ca_certificate::String

Returns PEM representation of the trusted CA's x509 certificate.

Returns:

  • (::String)

    PEM representation of the trusted CA's x509 certificate.



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#client_certificate::String

Returns PEM representation of the replica's x509 certificate.

Returns:

  • (::String)

    PEM representation of the replica's x509 certificate.



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#client_key::String

Returns PEM representation of the replica's private key. The corresponding public key is encoded in the client's certificate.

Returns:

  • (::String)

    PEM representation of the replica's private key. The corresponding public key is encoded in the client's certificate.



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#dms_managed::Boolean (readonly)

Returns Output only. Indicates whether the resource is managed by Database Migration Service.

Returns:

  • (::Boolean)

    Output only. Indicates whether the resource is managed by Database Migration Service.



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#dump_file_path::String

Returns The dump file to create the Cloud SQL replica.

Returns:

  • (::String)

    The dump file to create the Cloud SQL replica.



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#host_port::String

Returns The host and port of the on-premises instance in host:port format.

Returns:

  • (::String)

    The host and port of the on-premises instance in host:port format



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#kind::String

Returns This is always sql#onPremisesConfiguration.

Returns:

  • (::String)

    This is always sql#onPremisesConfiguration.



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#password::String

Returns The password for connecting to on-premises instance.

Returns:

  • (::String)

    The password for connecting to on-premises instance.



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#selected_objects::Array<::Google::Cloud::Sql::V1beta4::SelectedObjects>

Returns Optional. A list of objects that the user selects for replication from an external source instance.

Returns:



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#source_instance::Google::Cloud::Sql::V1beta4::InstanceReference

Returns The reference to Cloud SQL instance if the source is Cloud SQL.

Returns:



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#ssl_option::Google::Cloud::Sql::V1beta4::OnPremisesConfiguration::SslOption

Returns Optional. SslOption for replica connection to the on-premises source.

Returns:



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#username::String

Returns The username for connecting to on-premises instance.

Returns:

  • (::String)

    The username for connecting to on-premises instance.



2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2750

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is disabled for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end