Module: Google::Cloud::Sql::V1beta4::OnPremisesConfiguration::SslOption
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb
Overview
SslOption defines the SSL mode to be used for replica connection to the on-premises source.
Constant Summary collapse
- SSL_OPTION_UNSPECIFIED =
Unknown SSL option i.e. SSL option not specified by user.
0- DISABLE =
SSL is disabled for replica connection to the on-premises source.
1- REQUIRE =
SSL is required for replica connection to the on-premises source.
2- VERIFY_CA =
Verify CA is required for replica connection to the on-premises source.
3