Class: Google::Cloud::Sql::V1beta4::OperationErrors
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::OperationErrors
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb
Overview
Database instance operation errors list wrapper.
Instance Attribute Summary collapse
-
#errors ⇒ ::Array<::Google::Cloud::Sql::V1beta4::OperationError>
The list of errors encountered while processing this operation.
-
#kind ⇒ ::String
This is always
sql#operationErrors.
Instance Attribute Details
#errors ⇒ ::Array<::Google::Cloud::Sql::V1beta4::OperationError>
Returns The list of errors encountered while processing this operation.
3119 3120 3121 3122 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3119 class OperationErrors include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#operationErrors.
3119 3120 3121 3122 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3119 class OperationErrors include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |