Class: Google::Cloud::Sql::V1beta4::PasswordValidationPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb

Overview

Database instance local user password validation policy. This message defines the password policy for local database users. When enabled, it enforces constraints on password complexity, length, and reuse. Keep this policy enabled to help prevent unauthorized access.

Defined Under Namespace

Modules: Complexity

Instance Attribute Summary collapse

Instance Attribute Details

#complexity::Google::Cloud::Sql::V1beta4::PasswordValidationPolicy::Complexity



3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3154

class PasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The complexity choices of the password.
  module Complexity
    # Complexity check is not specified.
    COMPLEXITY_UNSPECIFIED = 0

    # A combination of lowercase, uppercase, numeric, and non-alphanumeric
    # characters.
    COMPLEXITY_DEFAULT = 1
  end
end

#disallow_compromised_credentials::Google::Protobuf::BoolValue

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns This field is deprecated and will be removed in a future version of the API.



3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3154

class PasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The complexity choices of the password.
  module Complexity
    # Complexity check is not specified.
    COMPLEXITY_UNSPECIFIED = 0

    # A combination of lowercase, uppercase, numeric, and non-alphanumeric
    # characters.
    COMPLEXITY_DEFAULT = 1
  end
end

#disallow_username_substring::Google::Protobuf::BoolValue



3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3154

class PasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The complexity choices of the password.
  module Complexity
    # Complexity check is not specified.
    COMPLEXITY_UNSPECIFIED = 0

    # A combination of lowercase, uppercase, numeric, and non-alphanumeric
    # characters.
    COMPLEXITY_DEFAULT = 1
  end
end

#enable_password_policy::Google::Protobuf::BoolValue



3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3154

class PasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The complexity choices of the password.
  module Complexity
    # Complexity check is not specified.
    COMPLEXITY_UNSPECIFIED = 0

    # A combination of lowercase, uppercase, numeric, and non-alphanumeric
    # characters.
    COMPLEXITY_DEFAULT = 1
  end
end

#min_length::Google::Protobuf::Int32Value



3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3154

class PasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The complexity choices of the password.
  module Complexity
    # Complexity check is not specified.
    COMPLEXITY_UNSPECIFIED = 0

    # A combination of lowercase, uppercase, numeric, and non-alphanumeric
    # characters.
    COMPLEXITY_DEFAULT = 1
  end
end

#password_change_interval::Google::Protobuf::Duration



3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3154

class PasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The complexity choices of the password.
  module Complexity
    # Complexity check is not specified.
    COMPLEXITY_UNSPECIFIED = 0

    # A combination of lowercase, uppercase, numeric, and non-alphanumeric
    # characters.
    COMPLEXITY_DEFAULT = 1
  end
end

#reuse_interval::Google::Protobuf::Int32Value



3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3154

class PasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The complexity choices of the password.
  module Complexity
    # Complexity check is not specified.
    COMPLEXITY_UNSPECIFIED = 0

    # A combination of lowercase, uppercase, numeric, and non-alphanumeric
    # characters.
    COMPLEXITY_DEFAULT = 1
  end
end