Class: Google::Cloud::Sql::V1beta4::PerformanceCaptureConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb

Overview

Performance capture configuration.

Defined Under Namespace

Modules: TransactionKillType

Instance Attribute Summary collapse

Instance Attribute Details

#cpu_utilization_threshold_percent::Integer

Returns Optional. Specifies the minimum percentage of CPU utilization to trigger the performance capture. Valid integers range from 10 to 99. Enter 0 to disable the check.

Returns:

  • (::Integer)

    Optional. Specifies the minimum percentage of CPU utilization to trigger the performance capture. Valid integers range from 10 to 99. Enter 0 to disable the check.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#enabled::Boolean

Returns Optional. Enables or disables the performance capture feature.

Returns:

  • (::Boolean)

    Optional. Enables or disables the performance capture feature.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#history_list_length_threshold_count::Integer

Returns Optional. Specifies the minimum number of undo log entries in the history list length to trigger the performance capture. Valid integers range from 10000 to 10000000. Enter 0 to disable the check.

Returns:

  • (::Integer)

    Optional. Specifies the minimum number of undo log entries in the history list length to trigger the performance capture. Valid integers range from 10000 to 10000000. Enter 0 to disable the check.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#memory_usage_threshold_percent::Integer

Returns Optional. Specifies the minimum percentage of memory usage to trigger the performance capture. Valid integers range from 10 to 99. Enter 0 to disable the check.

Returns:

  • (::Integer)

    Optional. Specifies the minimum percentage of memory usage to trigger the performance capture. Valid integers range from 10 to 99. Enter 0 to disable the check.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#probe_threshold::Integer

Returns Optional. Specifies the minimum number of consecutive probe threshold that triggers performance capture.

Returns:

  • (::Integer)

    Optional. Specifies the minimum number of consecutive probe threshold that triggers performance capture.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#probing_interval_seconds::Integer

Returns Optional. Specifies the interval in seconds between consecutive probes that check if any trigger condition thresholds have been reached.

Returns:

  • (::Integer)

    Optional. Specifies the interval in seconds between consecutive probes that check if any trigger condition thresholds have been reached.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#running_threads_threshold::Integer

Returns Optional. Specifies the minimum number of MySQL Threads_running to trigger the performance capture on the primary instance.

Returns:

  • (::Integer)

    Optional. Specifies the minimum number of MySQL Threads_running to trigger the performance capture on the primary instance.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#seconds_behind_source_threshold::Integer

Returns Optional. Specifies the minimum number of seconds replica must be lagging behind primary instance to trigger the performance capture on replica.

Returns:

  • (::Integer)

    Optional. Specifies the minimum number of seconds replica must be lagging behind primary instance to trigger the performance capture on replica.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#semaphore_wait_threshold_count::Integer

Returns Optional. Specifies the minimum allowed number of semaphore waits to trigger the performance capture. Valid integers range from 10 to 10000. Enter 0 to disable the check.

Returns:

  • (::Integer)

    Optional. Specifies the minimum allowed number of semaphore waits to trigger the performance capture. Valid integers range from 10 to 10000. Enter 0 to disable the check.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#transaction_duration_threshold::Integer

Returns Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts recording it.

Returns:

  • (::Integer)

    Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts recording it.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#transaction_kill_excluded_user_hosts::Array<::String>

Returns Optional. Specifies a customer-defined list of users to exclude from transaction termination. Entries can be in the format 'user@host' or just 'user'. A standalone 'user' implies 'user@%', excluding the user from any host. Wildcard '%' is allowed in the host part of the 'user@host' format. Example: ["app_user", "db_admin@10.1.2.3", "report_user@%"].

Returns:

  • (::Array<::String>)

    Optional. Specifies a customer-defined list of users to exclude from transaction termination. Entries can be in the format 'user@host' or just 'user'. A standalone 'user' implies 'user@%', excluding the user from any host. Wildcard '%' is allowed in the host part of the 'user@host' format. Example: ["app_user", "db_admin@10.1.2.3", "report_user@%"]



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#transaction_kill_threshold_seconds::Integer

Returns Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts terminating it. Valid integers range from 60 to 604800 (7 days). Enter 0 to disable. If enabled (i.e., > 0), this value must be greater than or equal to transaction_duration_threshold. Configurations where 0 < transaction_kill_threshold_seconds < transaction_duration_threshold will be rejected.

Returns:

  • (::Integer)

    Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts terminating it. Valid integers range from 60 to 604800 (7 days). Enter 0 to disable. If enabled (i.e., > 0), this value must be greater than or equal to transaction_duration_threshold. Configurations where 0 < transaction_kill_threshold_seconds < transaction_duration_threshold will be rejected.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#transaction_kill_type::Google::Cloud::Sql::V1beta4::PerformanceCaptureConfig::TransactionKillType

Returns Optional. Determines which transactions are allowed to be terminated when they exceed transaction_kill_threshold_seconds. This allows protecting write-heavy transactions from auto-termination if desired. Defaults to READ_ONLY_TRANSACTIONS if unspecified.

Returns:



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end

#transaction_lock_wait_threshold_count::Integer

Returns Optional. Specifies the minimum allowed number of transactions in lock wait state to trigger the performance capture. Valid integers range from 10 to 10000. Enter 0 to disable the check.

Returns:

  • (::Integer)

    Optional. Specifies the minimum allowed number of transactions in lock wait state to trigger the performance capture. Valid integers range from 10 to 10000. Enter 0 to disable the check.



3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3642

class PerformanceCaptureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the categories of long-running transactions eligible for automatic
  # termination by the Performance Capture.
  module TransactionKillType
    # Unspecified.
    TRANSACTION_KILL_TYPE_UNSPECIFIED = 0

    # Only read-only transactions are eligible for termination.
    READ_ONLY_TRANSACTIONS = 1

    # All transactions are eligible for termination, including those with write
    # operations (such as INSERT, UPDATE, DELETE, or DDL).
    ALL_TRANSACTIONS = 2
  end
end