Class: Google::Cloud::Sql::V1beta4::PreCheckResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::PreCheckResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb
Overview
Structured PreCheckResponse containing message, type, and required actions.
Defined Under Namespace
Modules: MessageType
Instance Attribute Summary collapse
-
#actions_required ⇒ ::Array<::String>
The actions that the user needs to take.
-
#message ⇒ ::String
The message to be displayed to the user.
-
#message_type ⇒ ::Google::Cloud::Sql::V1beta4::PreCheckResponse::MessageType
The type of message whether it is an info, warning, or error.
Instance Attribute Details
#actions_required ⇒ ::Array<::String>
Returns The actions that the user needs to take. Use repeated for multiple actions.
1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1980 class PreCheckResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of message which can be an info, a warning, or an error that # requires user intervention. module MessageType # Default unspecified value to prevent unintended behavior changes. MESSAGE_TYPE_UNSPECIFIED = 0 # General informational messages that don't require action. INFO = 1 # Warnings that might impact the upgrade but don't block it. WARNING = 2 # Errors that a user must resolve before proceeding with the upgrade. ERROR = 3 end end |
#message ⇒ ::String
Returns The message to be displayed to the user.
1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1980 class PreCheckResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of message which can be an info, a warning, or an error that # requires user intervention. module MessageType # Default unspecified value to prevent unintended behavior changes. MESSAGE_TYPE_UNSPECIFIED = 0 # General informational messages that don't require action. INFO = 1 # Warnings that might impact the upgrade but don't block it. WARNING = 2 # Errors that a user must resolve before proceeding with the upgrade. ERROR = 3 end end |
#message_type ⇒ ::Google::Cloud::Sql::V1beta4::PreCheckResponse::MessageType
Returns The type of message whether it is an info, warning, or error.
1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1980 class PreCheckResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of message which can be an info, a warning, or an error that # requires user intervention. module MessageType # Default unspecified value to prevent unintended behavior changes. MESSAGE_TYPE_UNSPECIFIED = 0 # General informational messages that don't require action. INFO = 1 # Warnings that might impact the upgrade but don't block it. WARNING = 2 # Errors that a user must resolve before proceeding with the upgrade. ERROR = 3 end end |