Class: Google::Cloud::Sql::V1beta4::RotateEntraIdCertificateContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb

Overview

Instance rotate Entra ID certificate context.

Instance Attribute Summary collapse

Instance Attribute Details

#kind::String

Returns Optional. This is always sql#rotateEntraIdCertificateContext.

Returns:

  • (::String)

    Optional. This is always sql#rotateEntraIdCertificateContext.



3269
3270
3271
3272
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3269

class RotateEntraIdCertificateContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_version::String

Returns Optional. The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added Entra ID certificate version.

Returns:

  • (::String)

    Optional. The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added Entra ID certificate version.



3269
3270
3271
3272
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3269

class RotateEntraIdCertificateContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end