Class: Google::Cloud::Sql::V1beta4::RotateServerCaContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb

Overview

Instance rotate server CA context.

Instance Attribute Summary collapse

Instance Attribute Details

#kind::String

Returns This is always sql#rotateServerCaContext.

Returns:

  • (::String)

    This is always sql#rotateServerCaContext.



3241
3242
3243
3244
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3241

class RotateServerCaContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_version::String

Returns The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server CA version.

Returns:

  • (::String)

    The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server CA version.



3241
3242
3243
3244
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3241

class RotateServerCaContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end