Class: Google::Cloud::Sql::V1beta4::RotateServerCertificateContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb

Overview

Instance rotate server certificate context.

Instance Attribute Summary collapse

Instance Attribute Details

#kind::String

Returns Optional. This is always sql#rotateServerCertificateContext.

Returns:

  • (::String)

    Optional. This is always sql#rotateServerCertificateContext.



3255
3256
3257
3258
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3255

class RotateServerCertificateContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_version::String

Returns Optional. The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server certificate version.

Returns:

  • (::String)

    Optional. The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server certificate version.



3255
3256
3257
3258
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3255

class RotateServerCertificateContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end