Class: Google::Cloud::Sql::V1beta4::SqlBackupRunsListRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::SqlBackupRunsListRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb
Instance Attribute Summary collapse
-
#instance ⇒ ::String
Cloud SQL instance ID, or "-" for all instances.
-
#max_results ⇒ ::Integer
Maximum number of backup runs per response.
-
#page_token ⇒ ::String
A previously-returned page token representing part of the larger set of results to view.
-
#project ⇒ ::String
Project ID of the project that contains the instance.
Instance Attribute Details
#instance ⇒ ::String
Returns Cloud SQL instance ID, or "-" for all instances. This does not include the project ID.
176 177 178 179 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 176 class SqlBackupRunsListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_results ⇒ ::Integer
Returns Maximum number of backup runs per response.
176 177 178 179 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 176 class SqlBackupRunsListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns A previously-returned page token representing part of the larger set of results to view.
176 177 178 179 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 176 class SqlBackupRunsListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID of the project that contains the instance.
176 177 178 179 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 176 class SqlBackupRunsListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |