Class: Google::Cloud::Sql::V1beta4::SqlDataService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/sql/v1beta4/sql_data_service/client.rb

Overview

Client for the SqlDataService service.

Service for streaming data to and from Cloud SQL instances.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#instance_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new SqlDataService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Sql::V1beta4::SqlDataService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Sql::V1beta4::SqlDataService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the SqlDataService client.

Yield Parameters:



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/google/cloud/sql/v1beta4/sql_data_service/client.rb', line 125

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/sql/v1beta4/cloud_sql_data_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @sql_data_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Sql::V1beta4::SqlDataService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @sql_data_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @sql_data_service_stub.endpoint
    config.universe_domain = @sql_data_service_stub.universe_domain
    config.logger = @sql_data_service_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Client)


189
190
191
# File 'lib/google/cloud/sql/v1beta4/sql_data_service/client.rb', line 189

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the SqlDataService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all SqlDataService clients
::Google::Cloud::Sql::V1beta4::SqlDataService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/google/cloud/sql/v1beta4/sql_data_service/client.rb', line 63

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Sql", "V1beta4"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the SqlDataService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



95
96
97
98
# File 'lib/google/cloud/sql/v1beta4/sql_data_service/client.rb', line 95

def configure
  yield @config if block_given?
  @config
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


196
197
198
# File 'lib/google/cloud/sql/v1beta4/sql_data_service/client.rb', line 196

def logger
  @sql_data_service_stub.logger
end

#stream_sql_data(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Sql::V1beta4::StreamSqlDataResponse>

StreamSqlData establishes a bidirectional stream to a Cloud SQL instance, and then streams data to and from the instance.

The first message from the client MUST be a StreamSqlDataRequest request with configuration settings, including required values for the connection_settings field. Subsequent messages from the client may contain the payload field.

Messages from the server may contain the payload field.

The payload fields of the request and response streams contain the raw data of the database's native wire protocol (e.g., PostgreSQL wire protocol). The database client is responsible for generating and parsing this data.

Any errors on initial connection (e.g., connection failure, authorization issues, network problems) will result in the stream being terminated with an appropriate RPC status exception.

After a successful connection is made, if an error occurs, then the server terminates connection and returns the appropriate RPC status exception.

Add the request params headers to the request to ensure that the streaming request is routed to the correct service for your database.

Use this format for the request params header:

x-goog-request-params: location_id={location_path}&instance_id={instance_path}`

location_path is locations/{location_name} instance_path is projects/{project_name}/instances/{instance_name}

for example: x-goog-request-params: location_id=locations/us-central1&instance_id=projects/myproject/instances/instancename

Examples:

Basic example

require "google/cloud/sql/v1beta4"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Sql::V1beta4::SqlDataService::Client.new

# Create an input stream.
input = Gapic::StreamInput.new

# Call the stream_sql_data method to start streaming.
output = client.stream_sql_data input

# Send requests on the stream. For each request object, set fields by
# passing keyword arguments. Be sure to close the stream when done.
input << Google::Cloud::Sql::V1beta4::StreamSqlDataRequest.new
input << Google::Cloud::Sql::V1beta4::StreamSqlDataRequest.new
input.close

# The returned object is a streamed enumerable yielding elements of type
# ::Google::Cloud::Sql::V1beta4::StreamSqlDataResponse
output.each do |current_response|
  p current_response
end

Parameters:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/google/cloud/sql/v1beta4/sql_data_service/client.rb', line 277

def stream_sql_data request, options = nil
  unless request.is_a? ::Enumerable
    raise ::ArgumentError, "request must be an Enumerable" unless request.respond_to? :to_enum
    request = request.to_enum
  end

  request = request.lazy.map do |req|
    ::Gapic::Protobuf.coerce req, to: ::Google::Cloud::Sql::V1beta4::StreamSqlDataRequest
  end

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.stream_sql_data..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Sql::V1beta4::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.stream_sql_data.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.stream_sql_data.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @sql_data_service_stub.call_rpc :stream_sql_data, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


105
106
107
# File 'lib/google/cloud/sql/v1beta4/sql_data_service/client.rb', line 105

def universe_domain
  @sql_data_service_stub.universe_domain
end