Class: Google::Cloud::Sql::V1beta4::SqlDatabasesUpdateRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::SqlDatabasesUpdateRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb
Instance Attribute Summary collapse
- #body ⇒ ::Google::Cloud::Sql::V1beta4::Database
-
#database ⇒ ::String
Name of the database to be updated in the instance.
-
#instance ⇒ ::String
Database instance ID.
-
#project ⇒ ::String
Project ID of the project that contains the instance.
Instance Attribute Details
#body ⇒ ::Google::Cloud::Sql::V1beta4::Database
244 245 246 247 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 244 class SqlDatabasesUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#database ⇒ ::String
Returns Name of the database to be updated in the instance.
244 245 246 247 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 244 class SqlDatabasesUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Database instance ID. This does not include the project ID.
244 245 246 247 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 244 class SqlDatabasesUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID of the project that contains the instance.
244 245 246 247 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 244 class SqlDatabasesUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |