Class: Google::Cloud::Sql::V1beta4::SqlInstancesExecuteSqlResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb

Overview

Execute SQL statements response.

Defined Under Namespace

Classes: Message

Instance Attribute Summary collapse

Instance Attribute Details

#messages::Array<::Google::Cloud::Sql::V1beta4::SqlInstancesExecuteSqlResponse::Message>

Returns A list of notices and warnings generated during query execution. For PostgreSQL, this includes all notices and warnings. For MySQL, this includes warnings generated by the last executed statement. To retrieve all warnings for a multi-statement query, SHOW WARNINGS must be executed after each statement.

Returns:

  • (::Array<::Google::Cloud::Sql::V1beta4::SqlInstancesExecuteSqlResponse::Message>)

    A list of notices and warnings generated during query execution. For PostgreSQL, this includes all notices and warnings. For MySQL, this includes warnings generated by the last executed statement. To retrieve all warnings for a multi-statement query, SHOW WARNINGS must be executed after each statement.



1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1166

class SqlInstancesExecuteSqlResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a notice or warning message from the database.
  # @!attribute [rw] message
  #   @return [::String]
  #     The full message string.
  #     For PostgreSQL, this is a formatted string that may include severity,
  #     code, and the notice/warning message.
  #     For MySQL, this contains the warning message.
  # @!attribute [rw] severity
  #   @return [::String]
  #     The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for
  #     MySQL).
  class Message
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#metadata::Google::Cloud::Sql::V1beta4::Metadata

Returns The additional metadata information regarding the execution of the SQL statements.

Returns:



1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1166

class SqlInstancesExecuteSqlResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a notice or warning message from the database.
  # @!attribute [rw] message
  #   @return [::String]
  #     The full message string.
  #     For PostgreSQL, this is a formatted string that may include severity,
  #     code, and the notice/warning message.
  #     For MySQL, this contains the warning message.
  # @!attribute [rw] severity
  #   @return [::String]
  #     The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for
  #     MySQL).
  class Message
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#results::Array<::Google::Cloud::Sql::V1beta4::QueryResult>

Returns The list of results after executing all the SQL statements.

Returns:



1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1166

class SqlInstancesExecuteSqlResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a notice or warning message from the database.
  # @!attribute [rw] message
  #   @return [::String]
  #     The full message string.
  #     For PostgreSQL, this is a formatted string that may include severity,
  #     code, and the notice/warning message.
  #     For MySQL, this contains the warning message.
  # @!attribute [rw] severity
  #   @return [::String]
  #     The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for
  #     MySQL).
  class Message
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#status::Google::Rpc::Status

Returns Contains the error from the database if the SQL execution failed.

Returns:



1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1166

class SqlInstancesExecuteSqlResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a notice or warning message from the database.
  # @!attribute [rw] message
  #   @return [::String]
  #     The full message string.
  #     For PostgreSQL, this is a formatted string that may include severity,
  #     code, and the notice/warning message.
  #     For MySQL, this contains the warning message.
  # @!attribute [rw] severity
  #   @return [::String]
  #     The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for
  #     MySQL).
  class Message
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end