Class: Google::Cloud::Sql::V1beta4::SqlInstancesExportRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb

Instance Attribute Summary collapse

Instance Attribute Details

#body::Google::Cloud::Sql::V1beta4::InstancesExportRequest



375
376
377
378
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 375

class SqlInstancesExportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance::String

Returns The Cloud SQL instance ID. This doesn't include the project ID.

Returns:

  • (::String)

    The Cloud SQL instance ID. This doesn't include the project ID.



375
376
377
378
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 375

class SqlInstancesExportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID of the project that contains the instance to be exported.

Returns:

  • (::String)

    Project ID of the project that contains the instance to be exported.



375
376
377
378
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 375

class SqlInstancesExportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end