Class: Google::Cloud::Sql::V1beta4::SqlInstancesGetLatestRecoveryTimeResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::SqlInstancesGetLatestRecoveryTimeResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb
Overview
Instance get latest recovery time response.
Instance Attribute Summary collapse
-
#earliest_recovery_time ⇒ ::Google::Protobuf::Timestamp
Timestamp, identifies the earliest recovery time of the source instance.
-
#kind ⇒ ::String
This is always
sql#getLatestRecoveryTime. -
#latest_recovery_time ⇒ ::Google::Protobuf::Timestamp
Timestamp, identifies the latest recovery time of the source instance.
Instance Attribute Details
#earliest_recovery_time ⇒ ::Google::Protobuf::Timestamp
Returns Timestamp, identifies the earliest recovery time of the source instance.
1037 1038 1039 1040 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1037 class SqlInstancesGetLatestRecoveryTimeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#getLatestRecoveryTime.
1037 1038 1039 1040 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1037 class SqlInstancesGetLatestRecoveryTimeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#latest_recovery_time ⇒ ::Google::Protobuf::Timestamp
Returns Timestamp, identifies the latest recovery time of the source instance.
1037 1038 1039 1040 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1037 class SqlInstancesGetLatestRecoveryTimeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |