Class: Google::Cloud::Sql::V1beta4::SqlInstancesInsertRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::SqlInstancesInsertRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb
Instance Attribute Summary collapse
- #body ⇒ ::Google::Cloud::Sql::V1beta4::DatabaseInstance
-
#project ⇒ ::String
Project ID of the project to which the newly created Cloud SQL instances should belong.
Instance Attribute Details
#body ⇒ ::Google::Cloud::Sql::V1beta4::DatabaseInstance
423 424 425 426 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 423 class SqlInstancesInsertRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID of the project to which the newly created Cloud SQL instances should belong.
423 424 425 426 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 423 class SqlInstancesInsertRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |