Class: Google::Cloud::Sql::V1beta4::SqlInstancesPatchRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb

Instance Attribute Summary collapse

Instance Attribute Details

#body::Google::Cloud::Sql::V1beta4::DatabaseInstance



507
508
509
510
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 507

class SqlInstancesPatchRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance::String

Returns Cloud SQL instance ID. This does not include the project ID.

Returns:

  • (::String)

    Cloud SQL instance ID. This does not include the project ID.



507
508
509
510
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 507

class SqlInstancesPatchRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID of the project that contains the instance.

Returns:

  • (::String)

    Project ID of the project that contains the instance.



507
508
509
510
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 507

class SqlInstancesPatchRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reconcile_psc_networking::Boolean

Returns Optional. Set PSC config to the same value as the existing config to reconcile the PSC networking.

Returns:

  • (::Boolean)

    Optional. Set PSC config to the same value as the existing config to reconcile the PSC networking.



507
508
509
510
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 507

class SqlInstancesPatchRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reconcile_psc_networking_force::Boolean

Returns Optional. Set PSC config to the same value as the existing config and force reconcile the PSC networking.

Returns:

  • (::Boolean)

    Optional. Set PSC config to the same value as the existing config and force reconcile the PSC networking.



507
508
509
510
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 507

class SqlInstancesPatchRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end