Class: Google::Cloud::Sql::V1beta4::SqlInstancesReleaseSsrsLeaseRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb

Overview

Request to release a lease for SSRS.

Instance Attribute Summary collapse

Instance Attribute Details

#instance::String

Returns Required. The Cloud SQL instance ID. This doesn't include the project ID. It's composed of lowercase letters, numbers, and hyphens, and it must start with a letter. The total length must be 98 characters or less (Example: instance-id).

Returns:

  • (::String)

    Required. The Cloud SQL instance ID. This doesn't include the project ID. It's composed of lowercase letters, numbers, and hyphens, and it must start with a letter. The total length must be 98 characters or less (Example: instance-id).



1068
1069
1070
1071
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1068

class SqlInstancesReleaseSsrsLeaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Required. The ID of the project that contains the instance (Example: project-id).

Returns:

  • (::String)

    Required. The ID of the project that contains the instance (Example: project-id).



1068
1069
1070
1071
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1068

class SqlInstancesReleaseSsrsLeaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end