Class: Google::Cloud::Sql::V1beta4::SqlInstancesRescheduleMaintenanceRequestBody

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb

Overview

Reschedule options for maintenance windows.

Defined Under Namespace

Modules: RescheduleType Classes: Reschedule

Instance Attribute Summary collapse

Instance Attribute Details

#reschedule::Google::Cloud::Sql::V1beta4::SqlInstancesRescheduleMaintenanceRequestBody::Reschedule

Returns Required. The type of the reschedule the user wants.

Returns:



3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3746

class SqlInstancesRescheduleMaintenanceRequestBody
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] reschedule_type
  #   @return [::Google::Cloud::Sql::V1beta4::SqlInstancesRescheduleMaintenanceRequestBody::RescheduleType]
  #     Required. The type of the reschedule.
  # @!attribute [rw] schedule_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. Timestamp when the maintenance shall be rescheduled to if
  #     reschedule_type=SPECIFIC_TIME, in
  #     [RFC 3339](https://tools.ietf.org/html/rfc3339) format, for example
  #     `2012-11-15T16:19:00.094Z`.
  class Reschedule
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module RescheduleType
    RESCHEDULE_TYPE_UNSPECIFIED = 0

    # Reschedules maintenance to happen now (within 5 minutes).
    IMMEDIATE = 1

    # Reschedules maintenance to occur within one week from the originally
    # scheduled day and time.
    NEXT_AVAILABLE_WINDOW = 2

    # Reschedules maintenance to a specific time and day.
    SPECIFIC_TIME = 3
  end
end