Class: Google::Cloud::Sql::V1beta4::SqlUsersUpdateRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb

Instance Attribute Summary collapse

Instance Attribute Details

#body::Google::Cloud::Sql::V1beta4::User



116
117
118
119
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 116

class SqlUsersUpdateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#database_roles::Array<::String>

Returns Optional. List of database roles to grant to the user. body.database_roles will be ignored for update request.

Returns:

  • (::Array<::String>)

    Optional. List of database roles to grant to the user. body.database_roles will be ignored for update request.



116
117
118
119
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 116

class SqlUsersUpdateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#host::String

Returns Optional. Host of the user in the instance.

Returns:

  • (::String)

    Optional. Host of the user in the instance.



116
117
118
119
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 116

class SqlUsersUpdateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance::String

Returns Database instance ID. This does not include the project ID.

Returns:

  • (::String)

    Database instance ID. This does not include the project ID.



116
117
118
119
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 116

class SqlUsersUpdateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Name of the user in the instance.

Returns:

  • (::String)

    Name of the user in the instance.



116
117
118
119
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 116

class SqlUsersUpdateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID of the project that contains the instance.

Returns:

  • (::String)

    Project ID of the project that contains the instance.



116
117
118
119
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 116

class SqlUsersUpdateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#revoke_existing_roles::Boolean

Returns Optional. Specifies whether to revoke existing roles that are not present in the database_roles field. If false or unset, the database roles specified in database_roles are added to the user's existing roles.

Returns:

  • (::Boolean)

    Optional. Specifies whether to revoke existing roles that are not present in the database_roles field. If false or unset, the database roles specified in database_roles are added to the user's existing roles.



116
117
118
119
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 116

class SqlUsersUpdateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#revoke_existing_server_roles::Boolean

Returns Optional. Specifies whether to revoke existing roles that are not present in the server_roles field. If false or unset, the server roles specified in server_roles are added to the user's existing server roles.

Returns:

  • (::Boolean)

    Optional. Specifies whether to revoke existing roles that are not present in the server_roles field. If false or unset, the server roles specified in server_roles are added to the user's existing server roles.



116
117
118
119
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 116

class SqlUsersUpdateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#server_roles::Array<::String>

Returns Optional. The server roles to grant to the SQL Server login. Existing server roles will not be revoked if revoke_existing_roles is false. body.server_roles will be ignored for update request.

Returns:

  • (::Array<::String>)

    Optional. The server roles to grant to the SQL Server login. Existing server roles will not be revoked if revoke_existing_roles is false. body.server_roles will be ignored for update request.



116
117
118
119
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 116

class SqlUsersUpdateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end