Class: Google::Cloud::Sql::V1beta4::SslCertsCreateEphemeralRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb

Overview

SslCerts create ephemeral certificate request.

Instance Attribute Summary collapse

Instance Attribute Details

#access_token::String

Returns Access token to include in the signed certificate.

Returns:

  • (::String)

    Access token to include in the signed certificate.



3727
3728
3729
3730
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3727

class SslCertsCreateEphemeralRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#public_key::String

Returns PEM encoded public key to include in the signed certificate.

Returns:

  • (::String)

    PEM encoded public key to include in the signed certificate.



3727
3728
3729
3730
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 3727

class SslCertsCreateEphemeralRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end