Class: Google::Cloud::Sql::V1beta4::StartSession

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb

Overview

Start a new session. The client must send this as the first message to the server to start a new session. The client may immediately send Data messages without waiting for a reply from the server.

Instance Attribute Summary collapse

Instance Attribute Details

#instance_id::String

Returns Required. The Cloud SQL instance resource name, for example: projects/example-project/instances/example-instance.

Returns:

  • (::String)

    Required. The Cloud SQL instance resource name, for example: projects/example-project/instances/example-instance



79
80
81
82
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 79

class StartSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location_id::String

Returns Required. location_id is used to route the request to a specific region. Use the same region which was used to create the instance. Use the format locations/{location}, for example: locations/us-central1.

Returns:

  • (::String)

    Required. location_id is used to route the request to a specific region. Use the same region which was used to create the instance. Use the format locations/{location}, for example: locations/us-central1.



79
80
81
82
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 79

class StartSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#session_id::String

Returns Optional. The session id, chosen by the client. This should be an unguessable string. If the client does not intend to reconnect to this session, the client may leave session_id unset.

Returns:

  • (::String)

    Optional. The session id, chosen by the client. This should be an unguessable string. If the client does not intend to reconnect to this session, the client may leave session_id unset.



79
80
81
82
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 79

class StartSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end