Class: Google::Cloud::Sql::V1beta4::StreamSqlDataResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb

Overview

Message sent from SqlDataService back to the client.

Instance Attribute Summary collapse

Instance Attribute Details

#ack::Google::Cloud::Sql::V1beta4::Ack

Returns Acknowledges data received by the server.

Returns:



127
128
129
130
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 127

class StreamSqlDataResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data::Google::Cloud::Sql::V1beta4::DataPacket

Returns Data from the database.

Note: The following fields are mutually exclusive: data, session_metadata, terminate_session. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Sql::V1beta4::DataPacket)

    Data from the database.

    Note: The following fields are mutually exclusive: data, session_metadata, terminate_session. If a field in that set is populated, all other fields in the set will automatically be cleared.



127
128
129
130
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 127

class StreamSqlDataResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#session_metadata::Google::Cloud::Sql::V1beta4::SessionMetadata

Returns The first message from the server to the client, containing metadata about this session.

Note: The following fields are mutually exclusive: session_metadata, data, terminate_session. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Sql::V1beta4::SessionMetadata)

    The first message from the server to the client, containing metadata about this session.

    Note: The following fields are mutually exclusive: session_metadata, data, terminate_session. If a field in that set is populated, all other fields in the set will automatically be cleared.



127
128
129
130
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 127

class StreamSqlDataResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#terminate_session::Google::Cloud::Sql::V1beta4::TerminateSession

Returns Terminates the session. This indicates that the database connection is closed. When the client receives this message, it should not attempt to reconnect.

Note: The following fields are mutually exclusive: terminate_session, session_metadata, data. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Sql::V1beta4::TerminateSession)

    Terminates the session. This indicates that the database connection is closed. When the client receives this message, it should not attempt to reconnect.

    Note: The following fields are mutually exclusive: terminate_session, session_metadata, data. If a field in that set is populated, all other fields in the set will automatically be cleared.



127
128
129
130
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 127

class StreamSqlDataResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end