Class: Google::Cloud::Sql::V1beta4::UsersListResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::UsersListResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb
Overview
User list response.
Instance Attribute Summary collapse
-
#items ⇒ ::Array<::Google::Cloud::Sql::V1beta4::User>
List of user resources in the instance.
-
#kind ⇒ ::String
This is always sql#usersList.
-
#next_page_token ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#items ⇒ ::Array<::Google::Cloud::Sql::V1beta4::User>
Returns List of user resources in the instance.
301 302 303 304 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 301 class UsersListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#usersList.
301 302 303 304 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 301 class UsersListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Unused.
301 302 303 304 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_users.rb', line 301 class UsersListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |