Class: Google::Cloud::Sql::V1beta4::Value

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb

Overview

The cell value of the table.

Instance Attribute Summary collapse

Instance Attribute Details

#null_value::Boolean

Returns If cell value is null, then this flag will be set to true.

Returns:

  • (::Boolean)

    If cell value is null, then this flag will be set to true.



1238
1239
1240
1241
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1238

class Value
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::String

Returns The cell value represented in string format.

Returns:

  • (::String)

    The cell value represented in string format.



1238
1239
1240
1241
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1238

class Value
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end