Class: Google::Cloud::Sql::V1beta4::Backup
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::Backup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb
Overview
A backup resource.
Defined Under Namespace
Modules: SqlBackupState, SqlBackupType
Instance Attribute Summary collapse
-
#backup_interval ⇒ ::Google::Type::Interval
readonly
Output only.
-
#backup_kind ⇒ ::Google::Cloud::Sql::V1beta4::SqlBackupKind
readonly
Output only.
-
#backup_run ⇒ ::String
readonly
Output only.
-
#database_version ⇒ ::Google::Cloud::Sql::V1beta4::SqlDatabaseVersion
readonly
Output only.
-
#description ⇒ ::String
The description of this backup.
-
#error ⇒ ::Google::Cloud::Sql::V1beta4::OperationError
readonly
Output only.
-
#expiry_time ⇒ ::Google::Protobuf::Timestamp
Backup expiration time.
-
#instance ⇒ ::String
The name of the database instance.
-
#instance_deletion_time ⇒ ::Google::Protobuf::Timestamp
readonly
Optional.
-
#instance_settings ⇒ ::Google::Cloud::Sql::V1beta4::DatabaseInstance
readonly
Optional.
-
#kind ⇒ ::String
readonly
Output only.
-
#kms_key ⇒ ::String
readonly
Output only.
-
#kms_key_version ⇒ ::String
readonly
Output only.
-
#location ⇒ ::String
The storage location of the backups.
-
#max_chargeable_bytes ⇒ ::Integer
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#satisfies_pzi ⇒ ::Google::Protobuf::BoolValue
readonly
Output only.
-
#satisfies_pzs ⇒ ::Google::Protobuf::BoolValue
readonly
Output only.
-
#self_link ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Sql::V1beta4::Backup::SqlBackupState
readonly
Output only.
-
#time_zone ⇒ ::String
readonly
Output only.
-
#ttl_days ⇒ ::Integer
Input only.
-
#type ⇒ ::Google::Cloud::Sql::V1beta4::Backup::SqlBackupType
readonly
Output only.
Instance Attribute Details
#backup_interval ⇒ ::Google::Type::Interval (readonly)
Returns Output only. This output contains the following values: start_time: All database writes up to this time are available. end_time: Any database writes after this time aren't available.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#backup_kind ⇒ ::Google::Cloud::Sql::V1beta4::SqlBackupKind (readonly)
Returns Output only. Specifies the kind of backup, PHYSICAL or DEFAULT_SNAPSHOT.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#backup_run ⇒ ::String (readonly)
Returns Output only. The mapping to backup run resource used for IAM validations.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#database_version ⇒ ::Google::Cloud::Sql::V1beta4::SqlDatabaseVersion (readonly)
Returns Output only. The database version of the instance of at the time this backup was made.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#description ⇒ ::String
Returns The description of this backup.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#error ⇒ ::Google::Cloud::Sql::V1beta4::OperationError (readonly)
Returns Output only. Information about why the backup operation fails (for example, when the backup state fails).
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#expiry_time ⇒ ::Google::Protobuf::Timestamp
Returns Backup expiration time. A UTC timestamp of when this resource expired.
Note: The following fields are mutually exclusive: expiry_time, ttl_days. If a field in that set is populated, all other fields in the set will automatically be cleared.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#instance ⇒ ::String
Returns The name of the database instance.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#instance_deletion_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Optional. Output only. Timestamp in UTC of when the instance associated with this backup is deleted.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#instance_settings ⇒ ::Google::Cloud::Sql::V1beta4::DatabaseInstance (readonly)
Returns Optional. Output only. Instance setting of the source instance that's associated with this backup.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#kind ⇒ ::String (readonly)
Returns Output only. This is always sql#backup.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#kms_key ⇒ ::String (readonly)
Returns Output only. This output contains the encryption configuration for a backup and the resource name of the KMS key for disk encryption.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#kms_key_version ⇒ ::String (readonly)
Returns Output only. This output contains the encryption status for a backup and the version of the KMS key that's used to encrypt the Cloud SQL instance.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#location ⇒ ::String
Returns The storage location of the backups. The location can be multi-regional.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#max_chargeable_bytes ⇒ ::Integer (readonly)
Returns Output only. The maximum chargeable bytes for the backup.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#name ⇒ ::String (readonly)
Returns Output only. The resource name of the backup. Format: projects/{project}/backups/{backup}.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#satisfies_pzi ⇒ ::Google::Protobuf::BoolValue (readonly)
Returns Output only. This status indicates whether the backup satisfies PZI.
The status is reserved for future use.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#satisfies_pzs ⇒ ::Google::Protobuf::BoolValue (readonly)
Returns Output only. This status indicates whether the backup satisfies PZS.
The status is reserved for future use.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#self_link ⇒ ::String (readonly)
Returns Output only. The URI of this resource.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#state ⇒ ::Google::Cloud::Sql::V1beta4::Backup::SqlBackupState (readonly)
Returns Output only. The state of this backup.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#time_zone ⇒ ::String (readonly)
Returns Output only. This output contains a backup time zone. If a Cloud SQL for SQL Server instance has a different time zone from the backup's time zone, then the restore to the instance doesn't happen.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#ttl_days ⇒ ::Integer
Returns Input only. The time-to-live (TTL) interval for this resource (in days). For example: ttlDays:7, means 7 days from the current time. The expiration time can't exceed 365 days from the time that the backup is created.
Note: The following fields are mutually exclusive: ttl_days, expiry_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |
#type ⇒ ::Google::Cloud::Sql::V1beta4::Backup::SqlBackupType (readonly)
Returns Output only. The type of this backup. The type can be "AUTOMATED", "ON_DEMAND", or “FINAL”.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 362 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The backup type. module SqlBackupType # This is an unknown backup type. SQL_BACKUP_TYPE_UNSPECIFIED = 0 # The backup schedule triggers a backup automatically. AUTOMATED = 1 # The user triggers a backup manually. ON_DEMAND = 2 # The backup that's created when the instance is deleted. FINAL = 3 end # The backup's state module SqlBackupState # The state of the backup is unknown. SQL_BACKUP_STATE_UNSPECIFIED = 0 # The backup that's added to a queue. ENQUEUED = 1 # The backup is in progress. RUNNING = 2 # The backup failed. FAILED = 3 # The backup is successful. SUCCESSFUL = 4 # The backup is being deleted. DELETING = 5 # Deletion of the backup failed. DELETION_FAILED = 6 end end |