Class: Google::Cloud::Sql::V1beta4::ContinueSession
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::ContinueSession
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb
Overview
Reconnects to an existing session. The client must send this as the first message to the server to reconnect to an existing session. The client may immediately send Data messages without waiting for a reply from the server.
Instance Attribute Summary collapse
-
#instance_id ⇒ ::String
Required.
-
#location_id ⇒ ::String
Required.
-
#session_id ⇒ ::String
Required.
Instance Attribute Details
#instance_id ⇒ ::String
Returns Required. The Cloud SQL instance resource name, for example: projects/example-project/instances/example-instance.
100 101 102 103 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 100 class ContinueSession include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#location_id ⇒ ::String
Returns Required. location_id is used to route the
request to a specific region. Use the same region which was used to create
the instance. Use the format locations/{location}, for example:
locations/us-central1.
100 101 102 103 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 100 class ContinueSession include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#session_id ⇒ ::String
Returns Required. The id of the session to reconnect.
100 101 102 103 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 100 class ContinueSession include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |