Class: Google::Cloud::Sql::V1beta4::ExecuteSqlPayload
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::ExecuteSqlPayload
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb
Overview
The request payload used to execute SQL statements.
Defined Under Namespace
Modules: PartialResultMode
Instance Attribute Summary collapse
-
#application ⇒ ::String
Optional.
-
#auto_iam_authn ⇒ ::Boolean
Optional.
-
#database ⇒ ::String
Optional.
-
#partial_result_mode ⇒ ::Google::Cloud::Sql::V1beta4::ExecuteSqlPayload::PartialResultMode
Optional.
-
#password_secret_version ⇒ ::String
Optional.
-
#row_limit ⇒ ::Integer
Optional.
-
#sql_statement ⇒ ::String
Required.
-
#user ⇒ ::String
Optional.
Instance Attribute Details
#application ⇒ ::String
Returns Optional. Specifies the name of the application that is making the request. This field is used for telemetry. Only alphanumeric characters, dashes, and underscores are allowed. The maximum length is 32 characters.
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127 class ExecuteSqlPayload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls how the API should respond when the SQL execution result exceeds # 10 MB. module PartialResultMode # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`. PARTIAL_RESULT_MODE_UNSPECIFIED = 0 # Throw an error if the result exceeds 10 MB or if only a partial result # can be retrieved. Don't return the result. FAIL_PARTIAL_RESULT = 1 # Return a truncated result and set `partial_result` to true if the result # exceeds 10 MB or if only a partial result can be retrieved due to error. # Don't throw an error. ALLOW_PARTIAL_RESULT = 2 end end |
#auto_iam_authn ⇒ ::Boolean
Returns Optional. When set to true, the API caller identity associated with the request is used for database authentication. The API caller must be an IAM user in the database.
Note: The following fields are mutually exclusive: auto_iam_authn, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127 class ExecuteSqlPayload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls how the API should respond when the SQL execution result exceeds # 10 MB. module PartialResultMode # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`. PARTIAL_RESULT_MODE_UNSPECIFIED = 0 # Throw an error if the result exceeds 10 MB or if only a partial result # can be retrieved. Don't return the result. FAIL_PARTIAL_RESULT = 1 # Return a truncated result and set `partial_result` to true if the result # exceeds 10 MB or if only a partial result can be retrieved due to error. # Don't throw an error. ALLOW_PARTIAL_RESULT = 2 end end |
#database ⇒ ::String
Returns Optional. Name of the database on which the statement will be executed.
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127 class ExecuteSqlPayload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls how the API should respond when the SQL execution result exceeds # 10 MB. module PartialResultMode # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`. PARTIAL_RESULT_MODE_UNSPECIFIED = 0 # Throw an error if the result exceeds 10 MB or if only a partial result # can be retrieved. Don't return the result. FAIL_PARTIAL_RESULT = 1 # Return a truncated result and set `partial_result` to true if the result # exceeds 10 MB or if only a partial result can be retrieved due to error. # Don't throw an error. ALLOW_PARTIAL_RESULT = 2 end end |
#partial_result_mode ⇒ ::Google::Cloud::Sql::V1beta4::ExecuteSqlPayload::PartialResultMode
Returns Optional. Controls how the API should respond when the SQL execution result is incomplete due to the size limit or another error. The default mode is to throw an error.
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127 class ExecuteSqlPayload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls how the API should respond when the SQL execution result exceeds # 10 MB. module PartialResultMode # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`. PARTIAL_RESULT_MODE_UNSPECIFIED = 0 # Throw an error if the result exceeds 10 MB or if only a partial result # can be retrieved. Don't return the result. FAIL_PARTIAL_RESULT = 1 # Return a truncated result and set `partial_result` to true if the result # exceeds 10 MB or if only a partial result can be retrieved due to error. # Don't throw an error. ALLOW_PARTIAL_RESULT = 2 end end |
#password_secret_version ⇒ ::String
Returns Optional. The resource name of the Secret Manager secret holding the
password for the user to log into the database. The secret should be
created using the regional endpoint (for API) or from the Regional
Secrets page (for UI), and stored in the same region as the Cloud SQL
instance. The expected resource name format is
projects/{project}/locations/{location}/secrets/{secret}/versions/{secret_version}.
This field is used together with the user field.
The secret resource name will not be stored.
Note: The following fields are mutually exclusive: password_secret_version, auto_iam_authn. If a field in that set is populated, all other fields in the set will automatically be cleared.
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127 class ExecuteSqlPayload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls how the API should respond when the SQL execution result exceeds # 10 MB. module PartialResultMode # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`. PARTIAL_RESULT_MODE_UNSPECIFIED = 0 # Throw an error if the result exceeds 10 MB or if only a partial result # can be retrieved. Don't return the result. FAIL_PARTIAL_RESULT = 1 # Return a truncated result and set `partial_result` to true if the result # exceeds 10 MB or if only a partial result can be retrieved due to error. # Don't throw an error. ALLOW_PARTIAL_RESULT = 2 end end |
#row_limit ⇒ ::Integer
Returns Optional. The maximum number of rows returned per SQL statement.
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127 class ExecuteSqlPayload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls how the API should respond when the SQL execution result exceeds # 10 MB. module PartialResultMode # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`. PARTIAL_RESULT_MODE_UNSPECIFIED = 0 # Throw an error if the result exceeds 10 MB or if only a partial result # can be retrieved. Don't return the result. FAIL_PARTIAL_RESULT = 1 # Return a truncated result and set `partial_result` to true if the result # exceeds 10 MB or if only a partial result can be retrieved due to error. # Don't throw an error. ALLOW_PARTIAL_RESULT = 2 end end |
#sql_statement ⇒ ::String
Returns Required. SQL statements to run on the database. It can be a single statement or a sequence of statements separated by semicolons.
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127 class ExecuteSqlPayload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls how the API should respond when the SQL execution result exceeds # 10 MB. module PartialResultMode # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`. PARTIAL_RESULT_MODE_UNSPECIFIED = 0 # Throw an error if the result exceeds 10 MB or if only a partial result # can be retrieved. Don't return the result. FAIL_PARTIAL_RESULT = 1 # Return a truncated result and set `partial_result` to true if the result # exceeds 10 MB or if only a partial result can be retrieved due to error. # Don't throw an error. ALLOW_PARTIAL_RESULT = 2 end end |
#user ⇒ ::String
Returns Optional. The name of an existing database user to connect to the database.
When auto_iam_authn is set to true, this field is ignored and the API
caller's IAM user is used.
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 1127 class ExecuteSqlPayload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls how the API should respond when the SQL execution result exceeds # 10 MB. module PartialResultMode # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`. PARTIAL_RESULT_MODE_UNSPECIFIED = 0 # Throw an error if the result exceeds 10 MB or if only a partial result # can be retrieved. Don't return the result. FAIL_PARTIAL_RESULT = 1 # Return a truncated result and set `partial_result` to true if the result # exceeds 10 MB or if only a partial result can be retrieved due to error. # Don't throw an error. ALLOW_PARTIAL_RESULT = 2 end end |