Class: Google::Cloud::Sql::V1beta4::InstancesDemoteRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::InstancesDemoteRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb
Overview
This request is used to demote an existing standalone instance to be a Cloud SQL read replica for an external database server.
Instance Attribute Summary collapse
Instance Attribute Details
#demote_context ⇒ ::Google::Cloud::Sql::V1beta4::DemoteContext
Returns Required. This context is used to demote an existing standalone instance to be a Cloud SQL read replica for an external database server.
1709 1710 1711 1712 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 1709 class InstancesDemoteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |