Class: Google::Cloud::Sql::V1beta4::SessionMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb

Overview

Metadata from the server to the client about the session. The server will always send this as the first message

Instance Attribute Summary collapse

Instance Attribute Details

#supported_features::Array<::Google::Cloud::Sql::V1beta4::SqlDataFeature>

Returns The features supported by the server for this session. This field is used by the client to determine which features are available on the server. The features supported by the server for this session.

Returns:

  • (::Array<::Google::Cloud::Sql::V1beta4::SqlDataFeature>)

    The features supported by the server for this session. This field is used by the client to determine which features are available on the server. The features supported by the server for this session.



139
140
141
142
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 139

class SessionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end