Module: Google::Cloud::Sql::V1beta4::SqlDataFeature
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb
Overview
The session features. The server must send the supported features in its first message to the client.
Constant Summary collapse
- SQL_DATA_FEATURE_UNSPECIFIED =
The feature is not specified. This value should not be used.
0- SQL_DATA_FEATURE_RECONNECT =
The server supports reconnecting to the session. If this feature is not present, the client should not attempt to reconnect to the session.
1