Class: Google::Cloud::Sql::V1beta4::SqlExternalSyncSettingError
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::SqlExternalSyncSettingError
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb
Overview
External primary instance migration setting error/warning.
Defined Under Namespace
Modules: SqlExternalSyncSettingErrorType
Instance Attribute Summary collapse
-
#detail ⇒ ::String
Additional information about the error encountered.
-
#kind ⇒ ::String
Can be
sql#externalSyncSettingErrororsql#externalSyncSettingWarning. -
#type ⇒ ::Google::Cloud::Sql::V1beta4::SqlExternalSyncSettingError::SqlExternalSyncSettingErrorType
Identifies the specific error that occurred.
Instance Attribute Details
#detail ⇒ ::String
Returns Additional information about the error encountered.
2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2057 class SqlExternalSyncSettingError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module SqlExternalSyncSettingErrorType SQL_EXTERNAL_SYNC_SETTING_ERROR_TYPE_UNSPECIFIED = 0 CONNECTION_FAILURE = 1 BINLOG_NOT_ENABLED = 2 INCOMPATIBLE_DATABASE_VERSION = 3 REPLICA_ALREADY_SETUP = 4 # The replication user is missing privileges that are required. INSUFFICIENT_PRIVILEGE = 5 # Unsupported migration type. UNSUPPORTED_MIGRATION_TYPE = 6 # No pglogical extension installed on databases, applicable for postgres. NO_PGLOGICAL_INSTALLED = 7 # pglogical node already exists on databases, applicable for postgres. PGLOGICAL_NODE_ALREADY_EXISTS = 8 # The value of parameter wal_level is not set to logical. INVALID_WAL_LEVEL = 9 # The value of parameter shared_preload_libraries does not include # pglogical. INVALID_SHARED_PRELOAD_LIBRARY = 10 # The value of parameter max_replication_slots is not sufficient. INSUFFICIENT_MAX_REPLICATION_SLOTS = 11 # The value of parameter max_wal_senders is not sufficient. INSUFFICIENT_MAX_WAL_SENDERS = 12 # The value of parameter max_worker_processes is not sufficient. INSUFFICIENT_MAX_WORKER_PROCESSES = 13 # Extensions installed are either not supported or having unsupported # versions UNSUPPORTED_EXTENSIONS = 14 # The value of parameter rds.logical_replication is not set to 1. INVALID_RDS_LOGICAL_REPLICATION = 15 # The primary instance logging setup doesn't allow EM sync. INVALID_LOGGING_SETUP = 16 # The primary instance database parameter setup doesn't allow EM sync. INVALID_DB_PARAM = 17 # The gtid_mode is not supported, applicable for MySQL. UNSUPPORTED_GTID_MODE = 18 # SQL Server Agent is not running. SQLSERVER_AGENT_NOT_RUNNING = 19 # The table definition is not support due to missing primary key or replica # identity, applicable for postgres. Note that this is a warning and won't # block the migration. UNSUPPORTED_TABLE_DEFINITION = 20 # The customer has a definer that will break EM setup. UNSUPPORTED_DEFINER = 21 # SQL Server @@SERVERNAME does not match actual host name. SQLSERVER_SERVERNAME_MISMATCH = 22 # The primary instance has been setup and will fail the setup. PRIMARY_ALREADY_SETUP = 23 # The primary instance has unsupported binary log format. UNSUPPORTED_BINLOG_FORMAT = 24 # The primary instance's binary log retention setting. BINLOG_RETENTION_SETTING = 25 # The primary instance has tables with unsupported storage engine. UNSUPPORTED_STORAGE_ENGINE = 26 # Source has tables with limited support # eg: PostgreSQL tables without primary keys. LIMITED_SUPPORT_TABLES = 27 # The replica instance contains existing data. EXISTING_DATA_IN_REPLICA = 28 # The replication user is missing privileges that are optional. MISSING_OPTIONAL_PRIVILEGES = 29 # Additional BACKUP_ADMIN privilege is granted to the replication user # which may lock source MySQL 8 instance for DDLs during initial sync. RISKY_BACKUP_ADMIN_PRIVILEGE = 30 # The Cloud Storage bucket is missing necessary permissions. INSUFFICIENT_GCS_PERMISSIONS = 31 # The Cloud Storage bucket has an error in the file or contains invalid # file information. INVALID_FILE_INFO = 32 # The source instance has unsupported database settings for migration. UNSUPPORTED_DATABASE_SETTINGS = 33 # The replication user is missing parallel import specific privileges. # (e.g. LOCK TABLES) for MySQL. MYSQL_PARALLEL_IMPORT_INSUFFICIENT_PRIVILEGE = 34 # The global variable local_infile is off on external server replica. LOCAL_INFILE_OFF = 35 # This code instructs customers to turn on point-in-time recovery manually # for the instance after promoting the Cloud SQL for PostgreSQL instance. TURN_ON_PITR_AFTER_PROMOTE = 36 # The minor version of replica database is incompatible with the source. INCOMPATIBLE_DATABASE_MINOR_VERSION = 37 # This warning message indicates that Cloud SQL uses the maximum number of # subscriptions to migrate data from the source to the destination. SOURCE_MAX_SUBSCRIPTIONS = 38 # Unable to verify definers on the source for MySQL. UNABLE_TO_VERIFY_DEFINERS = 39 # If a time out occurs while the subscription counts are calculated, then # this value is set to 1. Otherwise, this value is set to 2. SUBSCRIPTION_CALCULATION_STATUS = 40 # Count of subscriptions needed to sync source data for PostgreSQL # database. PG_SUBSCRIPTION_COUNT = 41 # Final parallel level that is used to do migration. PG_SYNC_PARALLEL_LEVEL = 42 # The disk size of the replica instance is smaller than the data size of # the source instance. INSUFFICIENT_DISK_SIZE = 43 # The data size of the source instance is greater than 1 TB, the number of # cores of the replica instance is less than 8, and the memory of the # replica is less than 32 GB. INSUFFICIENT_MACHINE_TIER = 44 # The warning message indicates the unsupported extensions will not be # migrated to the destination. UNSUPPORTED_EXTENSIONS_NOT_MIGRATED = 45 # The warning message indicates the pg_cron extension and settings will not # be migrated to the destination. EXTENSIONS_NOT_MIGRATED = 46 # The error message indicates that pg_cron flags are enabled on the # destination which is not supported during the migration. PG_CRON_FLAG_ENABLED_IN_REPLICA = 47 # This error message indicates that the specified extensions are not # enabled on destination instance. For example, before you can migrate # data to the destination instance, you must enable the PGAudit extension # on the instance. EXTENSIONS_NOT_ENABLED_IN_REPLICA = 48 # The source database has generated columns that can't be migrated. Please # change them to regular columns before migration. UNSUPPORTED_COLUMNS = 49 # The source database has users that aren't created in the replica. # First, create all users, which are in the pg_user_mappings table # of the source database, in the destination instance. Then, perform the # migration. USERS_NOT_CREATED_IN_REPLICA = 50 # The selected objects include system objects that aren't supported for # migration. UNSUPPORTED_SYSTEM_OBJECTS = 51 # The source database has tables with the FULL or NOTHING replica identity. # Before starting your migration, either remove the identity or change it # to DEFAULT. Note that this is an error and will block the migration. UNSUPPORTED_TABLES_WITH_REPLICA_IDENTITY = 52 # The selected objects don't exist on the source instance. SELECTED_OBJECTS_NOT_EXIST_ON_SOURCE = 53 # PSC only destination instance does not have a network attachment URI. PSC_ONLY_INSTANCE_WITH_NO_NETWORK_ATTACHMENT_URI = 54 # Selected objects reference unselected objects. Based on their object type # (foreign key constraint or view), selected objects will fail during # migration. SELECTED_OBJECTS_REFERENCE_UNSELECTED_OBJECTS = 55 # The migration will delete existing data in the replica; set # {::Google::Cloud::Sql::V1beta4::SqlInstancesStartExternalSyncRequest#replica_overwrite_enabled replica_overwrite_enabled} # in the request to acknowledge this. This is an error. MySQL only. PROMPT_DELETE_EXISTING = 56 # The migration will delete existing data in the replica; # {::Google::Cloud::Sql::V1beta4::SqlInstancesStartExternalSyncRequest#replica_overwrite_enabled replica_overwrite_enabled} # was set in the request acknowledging this. This is a warning rather than # an error. MySQL only. WILL_DELETE_EXISTING = 57 # The replication user is missing specific privileges to setup DDL # replication. (e.g. CREATE EVENT TRIGGER, CREATE SCHEMA) for PostgreSQL. PG_DDL_REPLICATION_INSUFFICIENT_PRIVILEGE = 58 end end |
#kind ⇒ ::String
Returns Can be sql#externalSyncSettingError or
sql#externalSyncSettingWarning.
2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2057 class SqlExternalSyncSettingError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module SqlExternalSyncSettingErrorType SQL_EXTERNAL_SYNC_SETTING_ERROR_TYPE_UNSPECIFIED = 0 CONNECTION_FAILURE = 1 BINLOG_NOT_ENABLED = 2 INCOMPATIBLE_DATABASE_VERSION = 3 REPLICA_ALREADY_SETUP = 4 # The replication user is missing privileges that are required. INSUFFICIENT_PRIVILEGE = 5 # Unsupported migration type. UNSUPPORTED_MIGRATION_TYPE = 6 # No pglogical extension installed on databases, applicable for postgres. NO_PGLOGICAL_INSTALLED = 7 # pglogical node already exists on databases, applicable for postgres. PGLOGICAL_NODE_ALREADY_EXISTS = 8 # The value of parameter wal_level is not set to logical. INVALID_WAL_LEVEL = 9 # The value of parameter shared_preload_libraries does not include # pglogical. INVALID_SHARED_PRELOAD_LIBRARY = 10 # The value of parameter max_replication_slots is not sufficient. INSUFFICIENT_MAX_REPLICATION_SLOTS = 11 # The value of parameter max_wal_senders is not sufficient. INSUFFICIENT_MAX_WAL_SENDERS = 12 # The value of parameter max_worker_processes is not sufficient. INSUFFICIENT_MAX_WORKER_PROCESSES = 13 # Extensions installed are either not supported or having unsupported # versions UNSUPPORTED_EXTENSIONS = 14 # The value of parameter rds.logical_replication is not set to 1. INVALID_RDS_LOGICAL_REPLICATION = 15 # The primary instance logging setup doesn't allow EM sync. INVALID_LOGGING_SETUP = 16 # The primary instance database parameter setup doesn't allow EM sync. INVALID_DB_PARAM = 17 # The gtid_mode is not supported, applicable for MySQL. UNSUPPORTED_GTID_MODE = 18 # SQL Server Agent is not running. SQLSERVER_AGENT_NOT_RUNNING = 19 # The table definition is not support due to missing primary key or replica # identity, applicable for postgres. Note that this is a warning and won't # block the migration. UNSUPPORTED_TABLE_DEFINITION = 20 # The customer has a definer that will break EM setup. UNSUPPORTED_DEFINER = 21 # SQL Server @@SERVERNAME does not match actual host name. SQLSERVER_SERVERNAME_MISMATCH = 22 # The primary instance has been setup and will fail the setup. PRIMARY_ALREADY_SETUP = 23 # The primary instance has unsupported binary log format. UNSUPPORTED_BINLOG_FORMAT = 24 # The primary instance's binary log retention setting. BINLOG_RETENTION_SETTING = 25 # The primary instance has tables with unsupported storage engine. UNSUPPORTED_STORAGE_ENGINE = 26 # Source has tables with limited support # eg: PostgreSQL tables without primary keys. LIMITED_SUPPORT_TABLES = 27 # The replica instance contains existing data. EXISTING_DATA_IN_REPLICA = 28 # The replication user is missing privileges that are optional. MISSING_OPTIONAL_PRIVILEGES = 29 # Additional BACKUP_ADMIN privilege is granted to the replication user # which may lock source MySQL 8 instance for DDLs during initial sync. RISKY_BACKUP_ADMIN_PRIVILEGE = 30 # The Cloud Storage bucket is missing necessary permissions. INSUFFICIENT_GCS_PERMISSIONS = 31 # The Cloud Storage bucket has an error in the file or contains invalid # file information. INVALID_FILE_INFO = 32 # The source instance has unsupported database settings for migration. UNSUPPORTED_DATABASE_SETTINGS = 33 # The replication user is missing parallel import specific privileges. # (e.g. LOCK TABLES) for MySQL. MYSQL_PARALLEL_IMPORT_INSUFFICIENT_PRIVILEGE = 34 # The global variable local_infile is off on external server replica. LOCAL_INFILE_OFF = 35 # This code instructs customers to turn on point-in-time recovery manually # for the instance after promoting the Cloud SQL for PostgreSQL instance. TURN_ON_PITR_AFTER_PROMOTE = 36 # The minor version of replica database is incompatible with the source. INCOMPATIBLE_DATABASE_MINOR_VERSION = 37 # This warning message indicates that Cloud SQL uses the maximum number of # subscriptions to migrate data from the source to the destination. SOURCE_MAX_SUBSCRIPTIONS = 38 # Unable to verify definers on the source for MySQL. UNABLE_TO_VERIFY_DEFINERS = 39 # If a time out occurs while the subscription counts are calculated, then # this value is set to 1. Otherwise, this value is set to 2. SUBSCRIPTION_CALCULATION_STATUS = 40 # Count of subscriptions needed to sync source data for PostgreSQL # database. PG_SUBSCRIPTION_COUNT = 41 # Final parallel level that is used to do migration. PG_SYNC_PARALLEL_LEVEL = 42 # The disk size of the replica instance is smaller than the data size of # the source instance. INSUFFICIENT_DISK_SIZE = 43 # The data size of the source instance is greater than 1 TB, the number of # cores of the replica instance is less than 8, and the memory of the # replica is less than 32 GB. INSUFFICIENT_MACHINE_TIER = 44 # The warning message indicates the unsupported extensions will not be # migrated to the destination. UNSUPPORTED_EXTENSIONS_NOT_MIGRATED = 45 # The warning message indicates the pg_cron extension and settings will not # be migrated to the destination. EXTENSIONS_NOT_MIGRATED = 46 # The error message indicates that pg_cron flags are enabled on the # destination which is not supported during the migration. PG_CRON_FLAG_ENABLED_IN_REPLICA = 47 # This error message indicates that the specified extensions are not # enabled on destination instance. For example, before you can migrate # data to the destination instance, you must enable the PGAudit extension # on the instance. EXTENSIONS_NOT_ENABLED_IN_REPLICA = 48 # The source database has generated columns that can't be migrated. Please # change them to regular columns before migration. UNSUPPORTED_COLUMNS = 49 # The source database has users that aren't created in the replica. # First, create all users, which are in the pg_user_mappings table # of the source database, in the destination instance. Then, perform the # migration. USERS_NOT_CREATED_IN_REPLICA = 50 # The selected objects include system objects that aren't supported for # migration. UNSUPPORTED_SYSTEM_OBJECTS = 51 # The source database has tables with the FULL or NOTHING replica identity. # Before starting your migration, either remove the identity or change it # to DEFAULT. Note that this is an error and will block the migration. UNSUPPORTED_TABLES_WITH_REPLICA_IDENTITY = 52 # The selected objects don't exist on the source instance. SELECTED_OBJECTS_NOT_EXIST_ON_SOURCE = 53 # PSC only destination instance does not have a network attachment URI. PSC_ONLY_INSTANCE_WITH_NO_NETWORK_ATTACHMENT_URI = 54 # Selected objects reference unselected objects. Based on their object type # (foreign key constraint or view), selected objects will fail during # migration. SELECTED_OBJECTS_REFERENCE_UNSELECTED_OBJECTS = 55 # The migration will delete existing data in the replica; set # {::Google::Cloud::Sql::V1beta4::SqlInstancesStartExternalSyncRequest#replica_overwrite_enabled replica_overwrite_enabled} # in the request to acknowledge this. This is an error. MySQL only. PROMPT_DELETE_EXISTING = 56 # The migration will delete existing data in the replica; # {::Google::Cloud::Sql::V1beta4::SqlInstancesStartExternalSyncRequest#replica_overwrite_enabled replica_overwrite_enabled} # was set in the request acknowledging this. This is a warning rather than # an error. MySQL only. WILL_DELETE_EXISTING = 57 # The replication user is missing specific privileges to setup DDL # replication. (e.g. CREATE EVENT TRIGGER, CREATE SCHEMA) for PostgreSQL. PG_DDL_REPLICATION_INSUFFICIENT_PRIVILEGE = 58 end end |
#type ⇒ ::Google::Cloud::Sql::V1beta4::SqlExternalSyncSettingError::SqlExternalSyncSettingErrorType
Returns Identifies the specific error that occurred.
2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_resources.rb', line 2057 class SqlExternalSyncSettingError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module SqlExternalSyncSettingErrorType SQL_EXTERNAL_SYNC_SETTING_ERROR_TYPE_UNSPECIFIED = 0 CONNECTION_FAILURE = 1 BINLOG_NOT_ENABLED = 2 INCOMPATIBLE_DATABASE_VERSION = 3 REPLICA_ALREADY_SETUP = 4 # The replication user is missing privileges that are required. INSUFFICIENT_PRIVILEGE = 5 # Unsupported migration type. UNSUPPORTED_MIGRATION_TYPE = 6 # No pglogical extension installed on databases, applicable for postgres. NO_PGLOGICAL_INSTALLED = 7 # pglogical node already exists on databases, applicable for postgres. PGLOGICAL_NODE_ALREADY_EXISTS = 8 # The value of parameter wal_level is not set to logical. INVALID_WAL_LEVEL = 9 # The value of parameter shared_preload_libraries does not include # pglogical. INVALID_SHARED_PRELOAD_LIBRARY = 10 # The value of parameter max_replication_slots is not sufficient. INSUFFICIENT_MAX_REPLICATION_SLOTS = 11 # The value of parameter max_wal_senders is not sufficient. INSUFFICIENT_MAX_WAL_SENDERS = 12 # The value of parameter max_worker_processes is not sufficient. INSUFFICIENT_MAX_WORKER_PROCESSES = 13 # Extensions installed are either not supported or having unsupported # versions UNSUPPORTED_EXTENSIONS = 14 # The value of parameter rds.logical_replication is not set to 1. INVALID_RDS_LOGICAL_REPLICATION = 15 # The primary instance logging setup doesn't allow EM sync. INVALID_LOGGING_SETUP = 16 # The primary instance database parameter setup doesn't allow EM sync. INVALID_DB_PARAM = 17 # The gtid_mode is not supported, applicable for MySQL. UNSUPPORTED_GTID_MODE = 18 # SQL Server Agent is not running. SQLSERVER_AGENT_NOT_RUNNING = 19 # The table definition is not support due to missing primary key or replica # identity, applicable for postgres. Note that this is a warning and won't # block the migration. UNSUPPORTED_TABLE_DEFINITION = 20 # The customer has a definer that will break EM setup. UNSUPPORTED_DEFINER = 21 # SQL Server @@SERVERNAME does not match actual host name. SQLSERVER_SERVERNAME_MISMATCH = 22 # The primary instance has been setup and will fail the setup. PRIMARY_ALREADY_SETUP = 23 # The primary instance has unsupported binary log format. UNSUPPORTED_BINLOG_FORMAT = 24 # The primary instance's binary log retention setting. BINLOG_RETENTION_SETTING = 25 # The primary instance has tables with unsupported storage engine. UNSUPPORTED_STORAGE_ENGINE = 26 # Source has tables with limited support # eg: PostgreSQL tables without primary keys. LIMITED_SUPPORT_TABLES = 27 # The replica instance contains existing data. EXISTING_DATA_IN_REPLICA = 28 # The replication user is missing privileges that are optional. MISSING_OPTIONAL_PRIVILEGES = 29 # Additional BACKUP_ADMIN privilege is granted to the replication user # which may lock source MySQL 8 instance for DDLs during initial sync. RISKY_BACKUP_ADMIN_PRIVILEGE = 30 # The Cloud Storage bucket is missing necessary permissions. INSUFFICIENT_GCS_PERMISSIONS = 31 # The Cloud Storage bucket has an error in the file or contains invalid # file information. INVALID_FILE_INFO = 32 # The source instance has unsupported database settings for migration. UNSUPPORTED_DATABASE_SETTINGS = 33 # The replication user is missing parallel import specific privileges. # (e.g. LOCK TABLES) for MySQL. MYSQL_PARALLEL_IMPORT_INSUFFICIENT_PRIVILEGE = 34 # The global variable local_infile is off on external server replica. LOCAL_INFILE_OFF = 35 # This code instructs customers to turn on point-in-time recovery manually # for the instance after promoting the Cloud SQL for PostgreSQL instance. TURN_ON_PITR_AFTER_PROMOTE = 36 # The minor version of replica database is incompatible with the source. INCOMPATIBLE_DATABASE_MINOR_VERSION = 37 # This warning message indicates that Cloud SQL uses the maximum number of # subscriptions to migrate data from the source to the destination. SOURCE_MAX_SUBSCRIPTIONS = 38 # Unable to verify definers on the source for MySQL. UNABLE_TO_VERIFY_DEFINERS = 39 # If a time out occurs while the subscription counts are calculated, then # this value is set to 1. Otherwise, this value is set to 2. SUBSCRIPTION_CALCULATION_STATUS = 40 # Count of subscriptions needed to sync source data for PostgreSQL # database. PG_SUBSCRIPTION_COUNT = 41 # Final parallel level that is used to do migration. PG_SYNC_PARALLEL_LEVEL = 42 # The disk size of the replica instance is smaller than the data size of # the source instance. INSUFFICIENT_DISK_SIZE = 43 # The data size of the source instance is greater than 1 TB, the number of # cores of the replica instance is less than 8, and the memory of the # replica is less than 32 GB. INSUFFICIENT_MACHINE_TIER = 44 # The warning message indicates the unsupported extensions will not be # migrated to the destination. UNSUPPORTED_EXTENSIONS_NOT_MIGRATED = 45 # The warning message indicates the pg_cron extension and settings will not # be migrated to the destination. EXTENSIONS_NOT_MIGRATED = 46 # The error message indicates that pg_cron flags are enabled on the # destination which is not supported during the migration. PG_CRON_FLAG_ENABLED_IN_REPLICA = 47 # This error message indicates that the specified extensions are not # enabled on destination instance. For example, before you can migrate # data to the destination instance, you must enable the PGAudit extension # on the instance. EXTENSIONS_NOT_ENABLED_IN_REPLICA = 48 # The source database has generated columns that can't be migrated. Please # change them to regular columns before migration. UNSUPPORTED_COLUMNS = 49 # The source database has users that aren't created in the replica. # First, create all users, which are in the pg_user_mappings table # of the source database, in the destination instance. Then, perform the # migration. USERS_NOT_CREATED_IN_REPLICA = 50 # The selected objects include system objects that aren't supported for # migration. UNSUPPORTED_SYSTEM_OBJECTS = 51 # The source database has tables with the FULL or NOTHING replica identity. # Before starting your migration, either remove the identity or change it # to DEFAULT. Note that this is an error and will block the migration. UNSUPPORTED_TABLES_WITH_REPLICA_IDENTITY = 52 # The selected objects don't exist on the source instance. SELECTED_OBJECTS_NOT_EXIST_ON_SOURCE = 53 # PSC only destination instance does not have a network attachment URI. PSC_ONLY_INSTANCE_WITH_NO_NETWORK_ATTACHMENT_URI = 54 # Selected objects reference unselected objects. Based on their object type # (foreign key constraint or view), selected objects will fail during # migration. SELECTED_OBJECTS_REFERENCE_UNSELECTED_OBJECTS = 55 # The migration will delete existing data in the replica; set # {::Google::Cloud::Sql::V1beta4::SqlInstancesStartExternalSyncRequest#replica_overwrite_enabled replica_overwrite_enabled} # in the request to acknowledge this. This is an error. MySQL only. PROMPT_DELETE_EXISTING = 56 # The migration will delete existing data in the replica; # {::Google::Cloud::Sql::V1beta4::SqlInstancesStartExternalSyncRequest#replica_overwrite_enabled replica_overwrite_enabled} # was set in the request acknowledging this. This is a warning rather than # an error. MySQL only. WILL_DELETE_EXISTING = 57 # The replication user is missing specific privileges to setup DDL # replication. (e.g. CREATE EVENT TRIGGER, CREATE SCHEMA) for PostgreSQL. PG_DDL_REPLICATION_INSUFFICIENT_PRIVILEGE = 58 end end |