Class: Google::Cloud::Sql::V1beta4::SqlInstancesVerifyExternalSyncSettingsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::SqlInstancesVerifyExternalSyncSettingsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb
Defined Under Namespace
Modules: ExternalSyncMode, MigrationType
Instance Attribute Summary collapse
-
#instance ⇒ ::String
Cloud SQL instance ID.
-
#migration_type ⇒ ::Google::Cloud::Sql::V1beta4::SqlInstancesVerifyExternalSyncSettingsRequest::MigrationType
Optional.
-
#mysql_sync_config ⇒ ::Google::Cloud::Sql::V1beta4::MySqlSyncConfig
Optional.
-
#project ⇒ ::String
Project ID of the project that contains the instance.
-
#selected_objects ⇒ ::Array<::Google::Cloud::Sql::V1beta4::ExternalSyncSelectedObject>
Optional.
-
#sync_mode ⇒ ::Google::Cloud::Sql::V1beta4::SqlInstancesVerifyExternalSyncSettingsRequest::ExternalSyncMode
External sync mode.
-
#sync_parallel_level ⇒ ::Google::Cloud::Sql::V1beta4::ExternalSyncParallelLevel
Optional.
-
#verify_connection_only ⇒ ::Boolean
Flag to enable verifying connection only.
-
#verify_replication_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#instance ⇒ ::String
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 806 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#migration_type ⇒ ::Google::Cloud::Sql::V1beta4::SqlInstancesVerifyExternalSyncSettingsRequest::MigrationType
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 806 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#mysql_sync_config ⇒ ::Google::Cloud::Sql::V1beta4::MySqlSyncConfig
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 806 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#project ⇒ ::String
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 806 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#selected_objects ⇒ ::Array<::Google::Cloud::Sql::V1beta4::ExternalSyncSelectedObject>
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 806 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#sync_mode ⇒ ::Google::Cloud::Sql::V1beta4::SqlInstancesVerifyExternalSyncSettingsRequest::ExternalSyncMode
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 806 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#sync_parallel_level ⇒ ::Google::Cloud::Sql::V1beta4::ExternalSyncParallelLevel
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 806 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#verify_connection_only ⇒ ::Boolean
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 806 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#verify_replication_only ⇒ ::Boolean
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql.rb', line 806 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |