Class: Google::Cloud::Sql::V1beta4::SqlTiersListRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::SqlTiersListRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_tiers.rb
Instance Attribute Summary collapse
-
#project ⇒ ::String
Project ID of the project for which to list tiers.
Instance Attribute Details
#project ⇒ ::String
Returns Project ID of the project for which to list tiers.
27 28 29 30 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_tiers.rb', line 27 class SqlTiersListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |