Class: Google::Cloud::Sql::V1beta4::StreamSqlDataRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1beta4::StreamSqlDataRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb
Overview
Message sent from the client to SqlDataService.
Instance Attribute Summary collapse
-
#ack ⇒ ::Google::Cloud::Sql::V1beta4::Ack
Optional.
-
#continue_session ⇒ ::Google::Cloud::Sql::V1beta4::ContinueSession
Continues an existing session.
-
#data ⇒ ::Google::Cloud::Sql::V1beta4::DataPacket
Database data.
-
#instance_id ⇒ ::String
Optional.
-
#start_session ⇒ ::Google::Cloud::Sql::V1beta4::StartSession
Starts a new session.
-
#terminate_session ⇒ ::Google::Cloud::Sql::V1beta4::TerminateSession
Terminates the session.
Instance Attribute Details
#ack ⇒ ::Google::Cloud::Sql::V1beta4::Ack
Returns Optional. Acknowledges data received by the client.
56 57 58 59 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 56 class StreamSqlDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#continue_session ⇒ ::Google::Cloud::Sql::V1beta4::ContinueSession
Returns Continues an existing session. When continuing an existing session, this is the first message the client sends.
Note: The following fields are mutually exclusive: continue_session, start_session, data, terminate_session. If a field in that set is populated, all other fields in the set will automatically be cleared.
56 57 58 59 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 56 class StreamSqlDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#data ⇒ ::Google::Cloud::Sql::V1beta4::DataPacket
Returns Database data.
Note: The following fields are mutually exclusive: data, start_session, continue_session, terminate_session. If a field in that set is populated, all other fields in the set will automatically be cleared.
56 57 58 59 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 56 class StreamSqlDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance_id ⇒ ::String
Returns Optional. Deprecated: Use StartSession.instance_id or
ContinueSession.instance_id instead.
The Cloud SQL instance resource name, for example:
projects/example-project/instances/example-instance.
56 57 58 59 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 56 class StreamSqlDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_session ⇒ ::Google::Cloud::Sql::V1beta4::StartSession
Returns Starts a new session. When starting a new session, this is the first message the client sends.
Note: The following fields are mutually exclusive: start_session, continue_session, data, terminate_session. If a field in that set is populated, all other fields in the set will automatically be cleared.
56 57 58 59 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 56 class StreamSqlDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#terminate_session ⇒ ::Google::Cloud::Sql::V1beta4::TerminateSession
Returns Terminates the session. This closes the connection to the database.
Note: The following fields are mutually exclusive: terminate_session, start_session, continue_session, data. If a field in that set is populated, all other fields in the set will automatically be cleared.
56 57 58 59 |
# File 'proto_docs/google/cloud/sql/v1beta4/cloud_sql_data.rb', line 56 class StreamSqlDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |